==> image_crawler_utils-0.1.6.tar.gz: image_crawler_utils-0.1.6/image_crawler_utils/stations/twitter/utils.py <==
from typing import Optional

import nodriver



async def twitter_progress_bar_loading(
    tab: nodriver.Tab,
) -> Optional[str]:
    """
    As long as there is an progress bar (rotating circle) in loading Twitter / X page, this function will not exit.

    Parameters:
        tab (nodriver.Tab): Nodriver tab with loaded searching result page.
    """
    
    while True:
        try:
            await tab.find('div[role="progressbar"]', timeout=1)
        except:
            break


async def twitter_error_check(
    tab: nodriver.Tab, 
) -> Optional[str]:
    """
    Check if there is an error in loading Twitter / X page.

    Parameters:
        tab (nodriver.Tab): Nodriver tab with loaded searching result page.

    Returns:
        Return True if found error element, or return False.
    """

    try:
        main_structure = await tab.find('div[data-testid="primaryColumn"]')
        error_element = await main_structure.query_selector('button[class="css-175oi2r r-sdzlij r-1phboty r-rs99b7 r-lrvibr r-2yi16 r-1qi8awa r-3pj75a r-1loqt21 r-o7ynqc r-6416eg r-1ny4l3l"]')
        return True if error_element is not None else False    
    except:
        return False
    

async def twitter_empty_check(
    tab: nodriver.Tab,
) -> Optional[str]:
    """
    Check if the result is empty.

    Parameters:
        tab (nodriver.Tab): Nodriver tab with loaded searching result page.
        tab_url (str): URL of the tab.
        log (crawler_utils.log.Log, optional): Logging config.

    Returns:
        Return True if found empty element, or return False.
    """

    try:
        await tab.sleep()
        await tab.find(r'div[data-testid="empty_state_header_text"], div[data-testid="empty_state_body_text"], a[href="/settings/search"]')
        return True
    except:
        return False

==> image_crawler_utils-0.3.2.tar.gz: image_crawler_utils-0.3.2/image_crawler_utils/stations/twitter/utils.py <==
from typing import Optional

import nodriver



async def twitter_progress_bar_loading(
    tab: nodriver.Tab,
) -> Optional[str]:
    """
    As long as there is an progress bar (rotating circle) in loading Twitter / X page, this function will not exit.

    Parameters:
        tab (nodriver.Tab): Nodriver tab with loaded searching result page.
    """
    
    while True:
        try:
            progressbar_elem = await tab.select('div[role="progressbar"]', timeout=1)
            if progressbar_elem is None:
                break
        except:
            break


async def twitter_error_check(
    tab: nodriver.Tab, 
) -> Optional[str]:
    """
    Check if there is an error in loading Twitter / X page.

    Parameters:
        tab (nodriver.Tab): Nodriver tab with loaded searching result page.

    Returns:
        Return True if found error element, or return False.
    """

    try:
        main_structure = await tab.select('div[data-testid="primaryColumn"]')
        error_element = await main_structure.query_selector('button[class="css-175oi2r r-sdzlij r-1phboty r-rs99b7 r-lrvibr r-2yi16 r-1qi8awa r-3pj75a r-1loqt21 r-o7ynqc r-6416eg r-1ny4l3l"]')
        return True if error_element is not None else False    
    except:
        return False
    

async def twitter_empty_check(
    tab: nodriver.Tab,
) -> Optional[str]:
    """
    Check if the result is empty.

    Parameters:
        tab (nodriver.Tab): Nodriver tab with loaded searching result page.
        tab_url (str): URL of the tab.
        log (crawler_utils.log.Log, optional): Logging config.

    Returns:
        Return True if found empty element, or return False.
    """

    try:
        await tab.sleep()
        empty_elem = await tab.select('div[data-testid="empty_state_header_text"]')
        return True if empty_elem is not None else False    
    except:
        return False
